import esbuild from "esbuild";
/**
 * Creates a bundle() function that can be used by build targets
 * to package the SSR code together with some platform specific
 * adapter logic.
 */
export function createBundler(ssrBundle) {
    const resolve = {
        name: "capri-resolve",
        setup(build) {
            build.onResolve({ filter: /^virtual:capri-ssr$/ }, () => {
                return { path: ssrBundle };
            });
        },
    };
    return async function bundle(input, output, options = {}) {
        const { target = "es2020", format = "esm", platform = "neutral", minify = true, inject, } = options;
        await esbuild.build({
            target,
            format,
            platform,
            plugins: [resolve],
            entryPoints: [input],
            inject,
            outfile: output,
            allowOverwrite: true,
            legalComments: "none",
            bundle: true,
            minify,
        });
    };
}
